# -*- coding: utf-8 -*-
"""Recipe phantomjs"""
import glob
import sys
import os


class Recipe(object):
    """zc.buildout recipe"""

    def __init__(self, buildout, name, options):
        self.buildout, self.name, self.options = buildout, name, options
        self.install_dir = os.path.join(
                                buildout['buildout']['parts-directory'], name)

    def get_binaries(self):
        binaries = glob.glob(os.path.join(self.install_dir, '*', 'bin', '*js'))
        binaries = dict([(os.path.basename(p), p) for p in binaries])
        if 'bootstrap.js' in binaries:
            del binaries['bootstrap.js']
        return binaries

    def download(self, url):
        from hexagonit.recipe.download import Recipe as Download
        options = self.options
        options['url'] = url
        dl = Download(self.buildout, self.name, options)
        dl.install()

    def install(self):
        """Installer"""
        binaries = self.get_binaries()
        if 'phantomjs' not in binaries:
            url = self.options.get('phantomjs-url', None)
            if not url:
                if sys.platform == 'linux2':
                    url = ('https://phantomjs.googlecode.com/'
                       'files/phantomjs-1.6.1-linux-x86_64-dynamic.tar.bz2')
                elif sys.platform == 'darwin':
                    url = ('https://phantomjs.googlecode.com/'
                        'files/phantomjs-1.6.1-macosx-static.zip')
                else:
                    raise RuntimeError('Please specify a phantomjs-url')
            self.download(url)
        if 'casperjs' not in binaries:
            self.download(self.options.get('casperjs-url',
                            'https://github.com/n1k0/casperjs/tarball/0.6.10'))

        self.options['eggs'] = 'gp.recipe.phantomjs'
        self.options['arguments'] = repr(binaries)
        self.options['entry-points'] = '\n'.join([
            '%s=gp.recipe.phantomjs.script:main' % s for s in binaries
            ])
        from zc.recipe.egg import Scripts
        rscripts = Scripts(self.buildout, self.name, self.options)
        return rscripts.install()

    update = install



# -*- coding: utf-8 -*-
import os
import sys


def main(binaries):
    os.environ['PHANTOMJS_EXECUTABLE'] = binaries['phantomjs']
    script_name = os.path.basename(sys.argv[0])
    script = binaries[script_name]
    args = [script] + sys.argv[1:]
    os.execve(args[0], args, os.environ)



# -*- coding: utf-8 -*-
"""
This module contains the tool of gp.recipe.phantomjs
"""
import os
from setuptools import setup, find_packages


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

version = '1.0'

long_description = (
    read('README.txt')
    + '\n' +
    'Detailed Documentation\n'
    '**********************\n'
    + '\n' +
    read('gp', 'recipe', 'phantomjs', 'README.txt')
    + '\n' +
    'Contributors\n'
    '************\n'
    + '\n' +
    read('CONTRIBUTORS.txt')
    + '\n' +
    'Change history\n'
    '**************\n'
    + '\n' +
    read('CHANGES.txt')
    + '\n' +
   'Download\n'
    '********\n')

entry_point = 'gp.recipe.phantomjs:Recipe'
entry_points = {"zc.buildout": ["default = %s" % entry_point]}

tests_require = ['zope.testing', 'zc.buildout']

setup(name='gp.recipe.phantomjs',
      version=version,
      description="buildout recipe to install phantomjs/casperjs",
      long_description=long_description,
      # Get more strings from
      # http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        'Framework :: Buildout',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        ],
      keywords='buildout phantomjs casperjs',
      author='Gael Pasgrimaud',
      author_email='gael@gawel.org',
      url='http://github.com/gawel/gp.recipe.phantomjs',
      license='gpl',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['gp', 'gp.recipe'],
      include_package_data=True,
      zip_safe=False,
      install_requires=['setuptools',
                        'zc.buildout',
                        'zc.recipe.egg',
                        'hexagonit.recipe.download',
                        ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      test_suite='gp.recipe.phantomjs.tests.test_docs.test_suite',
      entry_points=entry_points,
      )
